# Conversor & Divisor
![Conversor & Divisor](https://github.com/hadtrindade/conversor-e-divisor/workflows/Conversor%20&%20Divisor/badge.svg)
[![PyPI version](https://badge.fury.io/py/conversor-divisor.svg)](https://badge.fury.io/py/conversor-divisor)
[![Python 3](https://pyup.io/repos/github/hadtrindade/conversor-e-divisor/python-3-shield.svg)](https://pyup.io/repos/github/hadtrindade/conversor-e-divisor/)
[![CodeFactor](https://www.codefactor.io/repository/github/hadtrindade/conversor-e-divisor/badge)](https://www.codefactor.io/repository/github/hadtrindade/conversor-e-divisor)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Updates](https://pyup.io/repos/github/hadtrindade/conversor-e-divisor/shield.svg)](https://pyup.io/repos/github/hadtrindade/conversor-e-divisor/)

---

## Conversor & Divisor é uma GUI  - interface gráfica, gratuita e open-source para o FFmpeg e MP4Box a fim de realizar conversões e divisões de mídias para o PJe.


![Conversor & Divisor](https://i.imgur.com/whAnUwb.gif)


---

## Como instalar no windows
Baixar o instalador [Link](https://github.com/hadtrindade/conversor-e-divisor/releases)


## Como instalar no linux ou macOS.

    pip install conversor-divisor

## Para funcionamento no Linux ou macOS, os pacotes ffmpag e gpac(MP4Box) devem ser instalados no SO.

## Ubuntu:
    apt install ffmpeg gpac -y
## macOS:
    brew install ffmpeg gpac

### Download dos binários para Windows, caso queira instalar o conversor pelo código fonte [Link](https://drive.google.com/drive/folders/1h_ySXbsgu-hWg_ZKAWhqQx4mCNzQy3eU?usp=sharing).
